@@ -165,12 +165,16 @@ class MSCX(LoggedClass):
         ms_version = get_ms_version(self.mscx_src)
         if ms_version is None:
             raise ValueError(f"MuseScore version could not be read from {self.mscx_src}")
-        if ms_version[0] == '3':
+        major_version = int(ms_version[0])
+        if major_version == 3:
+            self.parse_mscx()
+        elif major_version == 4:
+            self.logger.info(f"This file has been created with MuseScore {ms_version} which I deal with experimentally for now.")
             self.parse_mscx()
         else:
             if self.parent_score.ms is None:
-                raise ValueError(f"""In order to parse a version {ms_version} file,
-use 'ms3 convert' command or pass parameter 'ms' to Score to temporally convert.""")
+                raise ValueError(f"In order to parse a version {ms_version} file, "
+                                 f"use 'ms3 convert' command or pass parameter 'ms' to Score to temporally convert.")
             with self.parent_score._tmp_convert(self.mscx_src) as tmp:
                 self.logger.debug(f"Using temporally converted file {os.path.basename(tmp)} for parsing the version {ms_version} file.")
                 self.mscx_src = tmp
